@@ -11,31 +11,31 @@ def cli():
 
 
 @cli.command()
-@click.argument("dsn")
+@click.option("--dsn", envvar="PGMIGRATIONS_DSN")
 def init(dsn):
     migrations = Migrations(dsn)
     migrations.init()
 
 
 @cli.command()
+@click.option("--dsn", envvar="PGMIGRATIONS_DSN")
 @click.argument("tag")
-@click.argument("dsn")
-def create(tag, dsn):
+def create(dsn, tag):
     migrations = Migrations()
     migrations.create(dsn, tag)
 
 
 @cli.command()
-@click.argument("dsn")
+@click.option("--dsn", envvar="PGMIGRATIONS_DSN")
 def apply(dsn):
     migrations = Migrations(dsn)
     migrations.apply()
 
 
 @cli.command()
+@click.option("--dsn", envvar="PGMIGRATIONS_DSN")
 @click.argument("name")
-@click.argument("dsn")
-def rollback(name, dsn):
+def rollback(dsn, name):
     migrations = Migrations(dsn)
     migrations.rollback(name)
 
